@@ -235,7 +235,7 @@ queries until after they have been run.
 =cut
 
 package Test::DBIC::ExpectedQueries;
-$Test::DBIC::ExpectedQueries::VERSION = '1.006';
+$Test::DBIC::ExpectedQueries::VERSION = '1.007';
 use Moo;
 BEGIN {extends "Attribute::Exporter"};
 
@@ -507,7 +507,9 @@ Many thanks to:
 
 =over 4
 
-=item Syohei YOSHIDA (syohex)
+=item *
+
+Syohei YOSHIDA (syohex)
 
 =back
 
